@@ -2,37 +2,32 @@
 
 
 package HiD;
-$HiD::VERSION = '1.8'; # TRIAL
+$HiD::VERSION = '1.92'; # TRIAL
 use Moose;
 use namespace::autoclean;
 # note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
-use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use Class::Load        qw/ :all /;
+use Class::Load        qw/ try_load_class /;
 use DateTime;
-use File::Basename;
 use File::Find::Rule;
-use File::Path         qw/ make_path /;
-use File::Remove       qw/ remove /;
+use Path::Tiny;
+use Try::Tiny;
+use YAML::XS           qw/ LoadFile /;
+
 use HiD::File;
 use HiD::Layout;
 use HiD::Page;
 use HiD::Pager;
 use HiD::Post;
 use HiD::Types;
-use Module::Find;
-use Path::Class        qw/ file /;
-use Try::Tiny;
-use YAML::XS           qw/ LoadFile /;
 
 
 has categories => (
@@ -130,7 +125,7 @@ has destination => (
   lazy    => 1 ,
   default => sub {
     my $dest = shift->get_config( 'destination' );
-    make_path $dest unless -e -d $dest;
+    path( $dest )->mkpath() unless -e -d $dest;
     return $dest;
   },
 );
@@ -616,9 +611,10 @@ sub publish {
   my( $self ) = @_;
 
   if ( -e $self->destination && $self->get_config( 'clean_destination' )){
-    remove( \1 , $self->destination );
+    my $path = path( $self->destination );
+    $path->remove_tree();
     $self->INFO( "cleaned destination directory" );
-    make_path $self->destination;
+    $path->mkpath();
   }
 
   $self->INFO( "publish" );
@@ -677,16 +673,19 @@ sub publish {
 
     $self->INFO( sprintf "* Published %s" , $file->output_filename );
 
-    my $path;
-    foreach my $part ( split '/' , $file->output_filename ) {
-      $path = file( $path , $part )->stringify;
-      $self->add_written_file( $path => 1 );
+    my $path = path( $file->output_filename );
+    while ( $path ne '.' ) {
+      $self->add_written_file( $path->stringify => 1 );
+      $path = $path->parent;
     }
   }
 
   if ( $self->remove_unwritten_files ) {
     foreach ( File::Find::Rule->in( $self->destination )) {
-      $self->wrote_file($_) or remove \1 , $_;
+      next if $self->wrote_file($_);
+
+      my $path = path( $_ );
+      $path->is_dir ? $path->remove_tree : $path->remove;
     }
   }
 
@@ -987,7 +986,7 @@ L<StaticVolt>
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -995,7 +994,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
