@@ -2,13 +2,13 @@
 
 
 package HiD::App::Command::server;
-$HiD::App::Command::server::VERSION = '1.8'; # TRIAL
+$HiD::App::Command::server::VERSION = '1.92'; # TRIAL
 use Moose;
 extends 'HiD::App::Command';
 with 'HiD::Role::PublishesDrafts';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
@@ -16,9 +16,7 @@ use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
 use feature     qw/ unicode_strings /;
 
-use namespace::autoclean;
-
-use Class::Load      qw/ :all /;
+use Class::Load      qw/ try_load_class /;
 use Plack::Builder;
 use Plack::Runner;
 
@@ -177,7 +175,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -185,7 +183,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
