@@ -2,19 +2,33 @@
 
 
 package HiD::Generator;
-$HiD::Generator::VERSION = '1.8'; # TRIAL
+$HiD::Generator::VERSION = '1.92'; # TRIAL
 use Moose::Role;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings   qw/ FATAL utf8 /;
 use charnames  qw/ :full           /;
-use feature    qw/ unicode_strings /;
+
+use Path::Tiny;
 
 requires 'generate';
 
 
+sub _create_destination_directory_if_needed {
+  my( $self , $dest ) = @_;
+
+  $dest = path( $dest );
+
+  $self->FATAL( "'$dest' exists and is not a directory!" )
+    if $dest->is_file;
+
+  $dest->mkpath;
+
+  return 1;
+}
+
 no Moose::Role;
 1;
 
@@ -49,7 +63,7 @@ $site->posts >> and so on.
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -57,7 +71,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
