@@ -2,8 +2,7 @@
 
 
 package HiD::Generator::ArchivePage;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Generator::ArchivePage::VERSION = '1.95_94'; # TRIAL
+$HiD::Generator::ArchivePage::VERSION = '1.92'; # TRIAL
 use Moose;
 with 'HiD::Generator';
 
@@ -85,7 +84,7 @@ published to, or let it default to the site-wide destination. Finally,
 
 =head1 VERSION
 
-version 1.95_94
+version 1.92
 
 =head1 AUTHOR
 
