@@ -2,23 +2,23 @@
 
 
 package HiD::Layout;
-$HiD::Layout::VERSION = '1.8'; # TRIAL
+$HiD::Layout::VERSION = '1.92'; # TRIAL
 use Moose;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Encode;
-use File::Slurp qw/ read_file / ;
-use HiD::Types;
+use Path::Tiny;
 use YAML::XS;
 
+use HiD::Types;
+
 
 has content => (
   is       => 'ro' ,
@@ -81,7 +81,7 @@ sub BUILDARGS {
     ( $args{name} , $args{ext} ) = $args{filename}
       =~ m|^.*/(.+)\.([^.]+)$|;
 
-    my $content  = read_file( $args{filename}, binmode => ':utf8' );
+    my $content  = path( $args{filename} )->slurp_utf8;
     my $metadata = {};
 
     if ( $content =~ /^---\n/s ) {
@@ -203,7 +203,7 @@ Will recurse into embedded layouts as needed.
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -211,7 +211,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
