@@ -2,18 +2,16 @@
 
 
 package HiD::Processor;
-$HiD::Processor::VERSION = '1.8'; # TRIAL
+$HiD::Processor::VERSION = '1.92'; # TRIAL
 use Moose;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
-
 
 ### FIXME figure out whether this makes more sense as a role that would make
 ###       it easier to see as something implementing a particular interface,
@@ -53,7 +51,7 @@ implements a 'process' method.
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -61,7 +59,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
