@@ -2,24 +2,23 @@
 
 
 package HiD::Role::IsPost;
-$HiD::Role::IsPost::VERSION = '1.8'; # TRIAL
+$HiD::Role::IsPost::VERSION = '1.92'; # TRIAL
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use DateTime;
 use Date::Parse    qw/ str2time  /;
-use File::Basename qw/ fileparse /;
-use HiD::Types;
 use YAML::XS;
 
+use HiD::Types;
+
 
 has author => (
   is      => 'ro' ,
@@ -292,7 +291,7 @@ folder or not.
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -300,7 +299,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
