@@ -2,21 +2,20 @@
 
 
 package HiD::Role::IsPublished;
-$HiD::Role::IsPublished::VERSION = '1.8'; # TRIAL
+$HiD::Role::IsPublished::VERSION = '1.92'; # TRIAL
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename  qw/ fileparse /;
+use Path::Tiny;
+
 use HiD::Types;
-use Path::Class     qw/ file /;
 
 requires 'publish';
 
@@ -31,7 +30,7 @@ has basename => (
 sub _build_basename {
   my $self = shift;
   my $ext = '.' . $self->ext;
-  return fileparse( $self->input_filename , $ext );
+  return path( $self->input_filename )->basename( $ext );
 }
 
 
@@ -83,11 +82,7 @@ has input_path => (
   is      => 'ro' ,
   isa     => 'HiD_DirPath' ,
   lazy    => 1 ,
-  default => sub {
-    my $self = shift;
-    my( undef , $path ) = fileparse( $self->input_filename );
-    return $path;
-  },
+  default => sub { path( shift->input_filename )->parent->stringify },
 );
 
 
@@ -101,7 +96,7 @@ has output_filename => (
     my $url = $self->url;
     $url .= 'index.html' if $url =~ m|/$|;
 
-    return file( $self->dest_dir , $url )->stringify;
+    return path( $self->dest_dir , $url )->stringify;
   },
 );
 
@@ -189,7 +184,7 @@ The URL to the output path for the written file.
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -197,7 +192,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
