@@ -1,6 +1,9 @@
+# ABSTRACT: Helper for 'hid server'
+
+
 package HiD::Server;
-$HiD::Server::VERSION = '1.8'; # TRIAL
-use strict;
+$HiD::Server::VERSION = '1.92'; # TRIAL
+use 5.014; # strict, unicode_strings
 use warnings;
 
 use parent 'Plack::App::File';
@@ -34,7 +37,11 @@ __END__
 
 =head1 NAME
 
-HiD::Server
+HiD::Server - Helper for 'hid server'
+
+=head1 DESCRIPTION
+
+Helper for C<hid server>
 
 =head1 METHODS
 
@@ -45,7 +52,7 @@ Overrides L<Plack::App::File>'s method of the same name to handle '/' and
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -53,7 +60,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
