@@ -1,6 +1,9 @@
+# ABSTRACT: Helper for 'hid publish -A'
+
+
 package HiD::Server::Handler;
-$HiD::Server::Handler::VERSION = '1.8'; # TRIAL
-use strict;
+$HiD::Server::Handler::VERSION = '1.92'; # TRIAL
+use 5.014;  # strict, unicode_strings
 use warnings;
 
 use parent 'Plack::Handler::Standalone';
@@ -11,7 +14,7 @@ sub new {
 
   my $hid = delete $args{hid};
 
-  die "I must be passed a HiD not a $hid!"
+  die "I must be passed something that can('publish') not a '$hid'!\n"
     unless defined $hid and $hid->can('publish');
 
   my $self = $class->SUPER::new(%args);
@@ -47,7 +50,7 @@ __END__
 
 =head1 NAME
 
-HiD::Server::Handler
+HiD::Server::Handler - Helper for 'hid publish -A'
 
 =head1 METHODS
 
@@ -60,9 +63,13 @@ Constructor.
 Handles resetting the embedded L<HiD> object and calling the C<publish> method
 on it.
 
+=head1
+
+Helper for C<hid publish -A>
+
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -70,7 +77,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
