@@ -1,6 +1,9 @@
+# ABSTRACT: Another helper for 'hid publish -A'
+
+
 package HiD::Server::Loader;
-$HiD::Server::Loader::VERSION = '1.8'; # TRIAL
-use strict;
+$HiD::Server::Loader::VERSION = '1.92'; # TRIAL
+use 5.014;  # strict, unicode_strings
 use warnings;
 
 use parent 'Plack::Loader::Restarter';
@@ -36,11 +39,15 @@ __END__
 
 =head1 NAME
 
-HiD::Server::Loader
+HiD::Server::Loader - Another helper for 'hid publish -A'
+
+=head1
+
+Another helper for C<hid publish -A>
 
 =head1 VERSION
 
-version 1.8
+version 1.92
 
 =head1 AUTHOR
 
@@ -48,7 +55,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
